import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk._jsii
import aws_solutions_constructs.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-solutions-constructs/aws-s3-sqs",
    "2.33.0",
    __name__[0:-6],
    "aws-s3-sqs@2.33.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
